GoogleSearch_services_types

Module GoogleSearch_services_types |
[hide private]
[frames] | no frames]

## Source Code for Module GoogleSearch_services_types

      1  ##################################################
      2  # GoogleSearch_services_types.py
      3  # generated by ZSI.wsdl2python
      4  #
      5  #
      6  ##################################################
      7
      8
      9  import ZSI
     10  from ZSI.TCcompound import Struct
     11
     12  ##############################
     13  # targetNamespace
     14  #
     15  # urn:GoogleSearch
     16  ##############################
     17
     18
     19  # imported as: ns1
     20 -class urn_GoogleSearch:
     21      targetNamespace = 'urn:GoogleSearch'
     22
     23 -    class DirectoryCategory_Def(ZSI.TCcompound.Struct):
     24          schema = 'urn:GoogleSearch'
     25          type = 'DirectoryCategory'
     26
     27 -        def __init__(self, name=None, ns=None, **kw):
     28              # internal vars
     29              self._fullViewableName = None
     30              self._specialEncoding = None
     31
     32              TClist = [ZSI.TC.String(pname="fullViewableName",aname="_fullViewableName"), ZSI.TC.String(pname="specialEncoding",aname="_specialEncoding"), ]
     33
     34              oname = name
     35
     36              if name:
     37                  aname = '_%s' % name
     38                  if ns:
     39                      oname += ' xmlns="%s"' % ns
     40                  else:
     41                      oname += ' xmlns="%s"' % self.__class__.schema
     42              else:
     43                  aname = None
     44
     45              ZSI.TCcompound.Struct.__init__(self, self.__class__, TClist,
     46                                             pname=name, inorder=0,
     47                                             aname=aname, oname=oname,
     48                                             **kw)
     49
     50 -    class ResultElementArray_Def(ZSI.TCcompound.Array):
     51 -        def __init__(self, name = None, ns = None, **kw):
     52              ZSI.TCcompound.Array.__init__(self, 'typens:ResultElement[]', ns1.ResultElement_Def(name=None), pname=name, aname='_%s' % name, oname='%s xmlns="urn:GoogleSearch"' % name, **kw)
     53
     54 -    class DirectoryCategoryArray_Def(ZSI.TCcompound.Array):
     55 -        def __init__(self, name = None, ns = None, **kw):
     56              ZSI.TCcompound.Array.__init__(self, 'typens:DirectoryCategory[]', ns1.DirectoryCategory_Def(name=None), pname=name, aname='_%s' % name, oname='%s xmlns="urn:GoogleSearch"' % name, **kw)
     57
     58 -    class ResultElement_Def(ZSI.TCcompound.Struct):
     59          schema = 'urn:GoogleSearch'
     60          type = 'ResultElement'
     61
     62 -        def __init__(self, name=None, ns=None, **kw):
     63              # internal vars
     64              self._summary = None
     65              self._URL = None
     66              self._snippet = None
     67              self._title = None
     68              self._cachedSize = None
     69              self._relatedInformationPresent = None
     70              self._hostName = None
     71              self._directoryCategory = None
     72              self._directoryTitle = None
     73
     74              TClist = [ZSI.TC.String(pname="summary",aname="_summary"), ZSI.TC.String(pname="URL",aname="_URL"), ZSI.TC.String(pname="snippet",aname="_snippet"), ZSI.TC.String(pname="title",aname="_title"), ZSI.TC.String(pname="cachedSize",aname="_cachedSize"), ZSI.TC.Boolean(pname="relatedInformationPresent",aname="_relatedInformationPresent"), ZSI.TC.String(pname="hostName",aname="_hostName"), ns1.DirectoryCategory_Def(name="directoryCategory", ns=ns), ZSI.TC.String(pname="directoryTitle",aname="_directoryTitle"), ]
     75
     76              oname = name
     77
     78              if name:
     79                  aname = '_%s' % name
     80                  if ns:
     81                      oname += ' xmlns="%s"' % ns
     82                  else:
     83                      oname += ' xmlns="%s"' % self.__class__.schema
     84              else:
     85                  aname = None
     86
     87              ZSI.TCcompound.Struct.__init__(self, self.__class__, TClist,
     88                                             pname=name, inorder=0,
     89                                             aname=aname, oname=oname,
     90                                             **kw)
     91
     92 -    class GoogleSearchResult_Def(ZSI.TCcompound.Struct):
     93          schema = 'urn:GoogleSearch'
     94          type = 'GoogleSearchResult'
     95
     96 -        def __init__(self, name=None, ns=None, **kw):
     97              # internal vars
     98              self._documentFiltering = None
     99              self._searchComments = None
    100              self._estimatedTotalResultsCount = None
    101              self._estimateIsExact = None
    102              self._resultElements = None
    103              self._searchQuery = None
    104              self._startIndex = None
    105              self._endIndex = None
    106              self._searchTips = None
    107              self._directoryCategories = None
    108              self._searchTime = None
    109
    110              TClist = [ZSI.TC.Boolean(pname="documentFiltering",aname="_documentFiltering"), ZSI.TC.String(pname="searchComments",aname="_searchComments"), ZSI.TCnumbers.Iint(pname="estimatedTotalResultsCount",aname="_estimatedTotalResultsCount"), ZSI.TC.Boolean(pname="estimateIsExact",aname="_estimateIsExact"), ns1.ResultElementArray_Def(name="resultElements", ns=ns), ZSI.TC.String(pname="searchQuery",aname="_searchQuery"), ZSI.TCnumbers.Iint(pname="startIndex",aname="_startIndex"), ZSI.TCnumbers.Iint(pname="endIndex",aname="_endIndex"), ZSI.TC.String(pname="searchTips",aname="_searchTips"), ns1.DirectoryCategoryArray_Def(name="directoryCategories", ns=ns), ZSI.TCnumbers.FPdouble(pname="searchTime",aname="_searchTime"), ]
    111
    112              oname = name
    113
    114              if name:
    115                  aname = '_%s' % name
    116                  if ns:
    117                      oname += ' xmlns="%s"' % ns
    118                  else:
    119                      oname += ' xmlns="%s"' % self.__class__.schema
    120              else:
    121                  aname = None
    122
    123              ZSI.TCcompound.Struct.__init__(self, self.__class__, TClist,
    124                                             pname=name, inorder=0,
    125                                             aname=aname, oname=oname,
    126                                             **kw)
    127
    128  # define class alias for subsequent ns classes
    129  ns1 = urn_GoogleSearch
    130